@@ -15,3 +15,14 @@ class CashbackType(str, Enum):
     none = "None"
     uah = "UAH"
     miles = "Miles"
+
+class CurrencyCode(int, Enum):
+    black = 980
+    eur = 978
+    usd = 840
+
+enum_encoders = {
+    CardType: lambda x: x.value,
+    CashbackType: lambda x: x.value,
+    CurrencyCode: lambda x: x.value,
+}
\ No newline at end of file
